@@ -580,13 +580,8 @@ QString ApplicationManager1Service::Identify(const QDBusUnixFileDescriptor &pidf
 
     Q_ASSERT_X(static_cast<bool>(m_identifier), "Identify", "Broken Identifier.");
 
-    auto pid = getPidFromPidFd(pidfd);
-    if (pid == 0) {
-        safe_sendErrorReply(QDBusError::Failed, "pid is invalid");
-        return {};
-    }
-
-    const auto ret = m_identifier->Identify(pid);
+    const auto ret = m_identifier->Identify(pidfd);
+    
     if (ret.ApplicationId.isEmpty()) {
         safe_sendErrorReply(QDBusError::Failed, "Identify failed.");
         return {};
